/* Copyright 2007 Deutsches Zentrum fuer Luft- und Raumfahrt e.V. (DLR)
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

#ifndef __dav_repos_H__
#define __dav_repos_H__

#include <mod_dav.h>
#include "dbms_mysql.h"

/* REMOVE DEBUG INFO */
#ifndef DEBUG
#undef DBG0
#undef DBG1
#undef DBG2
#undef DBG3
#define DBG0(A)
#define DBG1(A,B)
#define DBG2(A,B,C)
#define DBG3(A,B,C,D)
#endif

#define TRACE() DBG1("- TRACE : %s",  __func__ )

#ifndef VERSION
#define VERSION "static"
#endif

#ifdef __CYGWIN__
#define atoll(x)	strtoll(x, 0, 10)
#define atoull(x)	strtoull(x, 0, 10)
#endif


typedef struct
{
#ifdef USE_DIR
    const char *db_host;
    const char *db_name;
    const char *db_id;
    const char *db_pass;
    const char *tmp_dir;
    const char *file_dir;
    long max_file_size;
    int exact_search;

    apr_table_t *d_params;	/* per-directory DAV config parameters */

    dav_repos_dbms db;
#endif
}
dav_repos_dir_conf;


typedef struct
{
    const char *db_host;
    const char *db_name;
    const char *db_id;
    const char *db_pass;
    const char *tmp_dir;
    const char *file_dir;
    long max_file_size;
    int exact_search;

    apr_table_t *d_params;	/* per-directory DAV config parameters */

    dav_repos_dbms db;
}
dav_repos_server_conf;


/* dav_repos_server_conf is in repos.h */
typedef dav_repos_server_conf dav_repos_db;


/* our hooks structures; these are gathered into a dav_provider */
extern const dav_hooks_repository dav_repos_hooks_repos;
extern const dav_hooks_propdb     dav_repos_hooks_propdb;
extern const dav_hooks_search     dav_repos_hooks_search;
extern const dav_hooks_liveprop   dav_repos_hooks_liveprop;
extern const dav_hooks_vsn        dav_repos_hooks_vsn;
extern const dav_hooks_locks      dav_repos_hooks_locks;

extern const dav_liveprop_group dav_repos_liveprop_group;

/* handle the SEARCH method */
int dav_repos_method_search(request_rec * r);

void dav_repos_insert_all_liveprops(request_rec * r,
				    const dav_resource * resource,
				    dav_prop_insert what,
				    apr_text_header * phdr);
int dav_repos_find_liveprop(const dav_resource * resource, const char *ns_uri,
			    const char *name,
			    const dav_hooks_liveprop ** hooks);


/* some prototype */
const char *dav_repos_getetag(const dav_resource * resource);

#endif








